#!/usr/bin/env python
#
# Copyright (C) 2015 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from unittest.mock import MagicMock, patch
import pytest


from gns3.utils.server_select import server_select


def test_server_select_local_server(main_window, local_server):
    """
    With only local server we don't show the list of server
    """

    with patch("gns3.qt.QtWidgets.QInputDialog.getItem") as mock:
        server = server_select(main_window)

        assert not mock.called
        assert server == local_server


def test_server_select_local_server_local_disallow(main_window, local_server):
    """
    With only local server we don't show the list of server
    """

    with patch("gns3.qt.QtWidgets.QInputDialog.getItem") as mock:
        with pytest.raises(ValueError):
            server = server_select(main_window, allow_local_server=False)

            assert not mock.called


def test_server_select_local_server_and_remote_select_local(main_window, remote_server, local_server):

    with patch("gns3.qt.QtWidgets.QInputDialog.getItem", return_value=("Local server (http://127.0.0.1:3080)", True)) as mock:
        server = server_select(main_window)

        assert mock.called
        args, kwargs = mock.call_args
        assert args[3] == ["Local server (http://127.0.0.1:3080)", remote_server.url()]
        assert server.url() == local_server.url()


def test_server_select_local_server_and_remote_select_remote(main_window, remote_server, local_server):

    with patch("gns3.qt.QtWidgets.QInputDialog.getItem", return_value=(remote_server.url(), True)) as mock:
        server = server_select(main_window)

        assert mock.called
        args, kwargs = mock.call_args
        assert args[3] == ["Local server (http://127.0.0.1:3080)", remote_server.url()]
        assert server == remote_server


def test_server_select_local_server_and_remote_local_disallowed(main_window, remote_server, local_server):

    with patch("gns3.qt.QtWidgets.QInputDialog.getItem", return_value=(remote_server.url(), True)) as mock:
        server = server_select(main_window, allow_local_server=False)

        assert not mock.called
        assert server == remote_server


def test_server_select_local_server_and_gns3_vm_select_vm(main_window, gns3vm_server, local_server):

    with patch("gns3.qt.QtWidgets.QInputDialog.getItem", return_value=("GNS3 VM", True)) as mock:
        server = server_select(main_window)

        assert mock.called
        args, kwargs = mock.call_args
        assert args[3] == ["Local server (http://127.0.0.1:3080)", "GNS3 VM (http://unset:3080)"]
        assert server == gns3vm_server


def test_server_select_local_server_and_remote_user_cancel(main_window, remote_server, local_server):

    with patch("gns3.qt.QtWidgets.QInputDialog.getItem", return_value=("Local server (http://127.0.0.1:3080)", False)) as mock:
        server = server_select(main_window)

        assert mock.called
        args, kwargs = mock.call_args
        assert server is None



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/noplay/code/gns3/gns3-gui/gns3/ui/new_server_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.6
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_NewServerDialog(object):
    def setupUi(self, NewServerDialog):
        NewServerDialog.setObjectName("NewServerDialog")
        NewServerDialog.setWindowModality(QtCore.Qt.WindowModal)
        NewServerDialog.resize(426, 304)
        self.verticalLayout = QtWidgets.QVBoxLayout(NewServerDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(NewServerDialog)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.uiServerProtocolLabel = QtWidgets.QLabel(self.groupBox)
        self.uiServerProtocolLabel.setObjectName("uiServerProtocolLabel")
        self.gridLayout.addWidget(self.uiServerProtocolLabel, 0, 0, 1, 1)
        self.uiServerProtocolComboBox = QtWidgets.QComboBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiServerProtocolComboBox.sizePolicy().hasHeightForWidth())
        self.uiServerProtocolComboBox.setSizePolicy(sizePolicy)
        self.uiServerProtocolComboBox.setObjectName("uiServerProtocolComboBox")
        self.uiServerProtocolComboBox.addItem("")
        self.uiServerProtocolComboBox.addItem("")
        self.gridLayout.addWidget(self.uiServerProtocolComboBox, 0, 1, 1, 2)
        self.uiServerHostLabel = QtWidgets.QLabel(self.groupBox)
        self.uiServerHostLabel.setObjectName("uiServerHostLabel")
        self.gridLayout.addWidget(self.uiServerHostLabel, 1, 0, 1, 1)
        self.uiServerHostLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.uiServerHostLineEdit.setObjectName("uiServerHostLineEdit")
        self.gridLayout.addWidget(self.uiServerHostLineEdit, 1, 1, 1, 2)
        self.uiServerPortLabel = QtWidgets.QLabel(self.groupBox)
        self.uiServerPortLabel.setObjectName("uiServerPortLabel")
        self.gridLayout.addWidget(self.uiServerPortLabel, 2, 0, 1, 1)
        self.uiServerPortSpinBox = QtWidgets.QSpinBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiServerPortSpinBox.sizePolicy().hasHeightForWidth())
        self.uiServerPortSpinBox.setSizePolicy(sizePolicy)
        self.uiServerPortSpinBox.setSuffix(" TCP")
        self.uiServerPortSpinBox.setMaximum(65535)
        self.uiServerPortSpinBox.setProperty("value", 3080)
        self.uiServerPortSpinBox.setObjectName("uiServerPortSpinBox")
        self.gridLayout.addWidget(self.uiServerPortSpinBox, 2, 1, 1, 2)
        self.uiEnableAuthenticationCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.uiEnableAuthenticationCheckBox.setObjectName("uiEnableAuthenticationCheckBox")
        self.gridLayout.addWidget(self.uiEnableAuthenticationCheckBox, 3, 0, 1, 3)
        self.uiServerUserLabel = QtWidgets.QLabel(self.groupBox)
        self.uiServerUserLabel.setObjectName("uiServerUserLabel")
        self.gridLayout.addWidget(self.uiServerUserLabel, 4, 0, 1, 2)
        self.uiServerUserLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.uiServerUserLineEdit.setEnabled(False)
        self.uiServerUserLineEdit.setToolTip("")
        self.uiServerUserLineEdit.setObjectName("uiServerUserLineEdit")
        self.gridLayout.addWidget(self.uiServerUserLineEdit, 4, 2, 1, 1)
        self.uiServerPasswordLabel = QtWidgets.QLabel(self.groupBox)
        self.uiServerPasswordLabel.setObjectName("uiServerPasswordLabel")
        self.gridLayout.addWidget(self.uiServerPasswordLabel, 5, 0, 1, 2)
        self.uiServerPasswordLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.uiServerPasswordLineEdit.setEnabled(False)
        self.uiServerPasswordLineEdit.setInputMethodHints(QtCore.Qt.ImhHiddenText|QtCore.Qt.ImhNoAutoUppercase|QtCore.Qt.ImhNoPredictiveText|QtCore.Qt.ImhSensitiveData)
        self.uiServerPasswordLineEdit.setEchoMode(QtWidgets.QLineEdit.Password)
        self.uiServerPasswordLineEdit.setObjectName("uiServerPasswordLineEdit")
        self.gridLayout.addWidget(self.uiServerPasswordLineEdit, 5, 2, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)
        self.buttonBox = QtWidgets.QDialogButtonBox(NewServerDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)
        spacerItem = QtWidgets.QSpacerItem(20, 21, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)

        self.retranslateUi(NewServerDialog)
        self.buttonBox.accepted.connect(NewServerDialog.accept)
        self.buttonBox.rejected.connect(NewServerDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(NewServerDialog)

    def retranslateUi(self, NewServerDialog):
        _translate = QtCore.QCoreApplication.translate
        NewServerDialog.setWindowTitle(_translate("NewServerDialog", "New server"))
        self.groupBox.setTitle(_translate("NewServerDialog", "Server settings"))
        self.uiServerProtocolLabel.setText(_translate("NewServerDialog", "Protocol:"))
        self.uiServerProtocolComboBox.setCurrentText(_translate("NewServerDialog", "HTTP"))
        self.uiServerProtocolComboBox.setItemText(0, _translate("NewServerDialog", "HTTP"))
        self.uiServerProtocolComboBox.setItemText(1, _translate("NewServerDialog", "HTTPS"))
        self.uiServerHostLabel.setText(_translate("NewServerDialog", "Host:"))
        self.uiServerHostLineEdit.setText(_translate("NewServerDialog", "192.168.56.101"))
        self.uiServerPortLabel.setText(_translate("NewServerDialog", "Port:"))
        self.uiEnableAuthenticationCheckBox.setText(_translate("NewServerDialog", "Enable authentication"))
        self.uiServerUserLabel.setText(_translate("NewServerDialog", "User:"))
        self.uiServerPasswordLabel.setText(_translate("NewServerDialog", "Password:"))




# -*- coding: utf-8 -*-
#
# Copyright (C) 2014 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Configuration page for Dynamips Ethernet hubs.
"""

from gns3.qt import QtWidgets
from gns3.dialogs.node_properties_dialog import ConfigurationError
from ..ui.ethernet_hub_configuration_page_ui import Ui_ethernetHubConfigPageWidget


class EthernetHubConfigurationPage(QtWidgets.QWidget, Ui_ethernetHubConfigPageWidget):

    """
    QWidget configuration page for Ethernet hubs.
    """

    def __init__(self):

        super().__init__()
        self.setupUi(self)

    def loadSettings(self, settings, node, group=False):
        """
        Loads the Ethernet hub settings.

        :param settings: the settings (dictionary)
        :param node: Node instance
        :param group: indicates the settings apply to a group
        """

        if not group:
            self.uiNameLineEdit.setText(settings["name"])
        else:
            self.uiNameLineEdit.hide()
            self.uiNameLabel.hide()

        nbports = len(settings["ports"])
        self.uiPortsSpinBox.setValue(nbports)

    def saveSettings(self, settings, node, group=False):
        """
        Saves the Ethernet hub settings.

        :param settings: the settings (dictionary)
        :param node: Node instance
        :param group: indicates the settings apply to a group
        """

        if not group:
            # set the device name
            name = self.uiNameLineEdit.text()
            if not name:
                QtWidgets.QMessageBox.critical(self, "Name", "Ethernet hub name cannot be empty!")
            else:
                settings["name"] = name
        else:
            del settings["name"]

        nbports = self.uiPortsSpinBox.value()

        # check that a link isn't connected to a port
        # before we delete it
        ports = node.ports()
        for port in ports:
            if not port.isFree() and port.portNumber() > nbports:
                self.loadSettings(settings, node)
                QtWidgets.QMessageBox.critical(self, node.name(), "A link is connected to port {}, please remove it first".format(port.name()))
                raise ConfigurationError()

        settings["ports"] = []
        for port in range(1, nbports + 1):
            settings["ports"].append(str(port))



# -*- coding: utf-8 -*-
#
# Copyright (C) 2015 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Default Docker settings.
"""

import sys
from gns3.node import Node

DOCKER_SETTINGS = {
    "use_local_server": sys.platform.startswith("linux"),  # Docker only supported on Linux
    "containers": []
}

DOCKER_CONTAINER_SETTINGS = {
    "default_name_format": "{name}-{0}",
    "symbol": ":/symbols/docker_guest.svg",
    "category": Node.end_devices,
    "start_command": "",
    "name": "",
    "image": "",
    "adapters": 1,
    "environment": "",
    "console_type": "telnet",
    "console_resolution": "1024x768",
    "console_http_port": 80,
    "console_http_path": "/"
}



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/noplay/code/gns3/gns3-gui/gns3/modules/dynamips/ui/atm_bridge_configuration_page.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_atmBridgeConfigPageWidget(object):

    def setupUi(self, atmBridgeConfigPageWidget):
        atmBridgeConfigPageWidget.setObjectName("atmBridgeConfigPageWidget")
        atmBridgeConfigPageWidget.resize(432, 358)
        self.gridLayout_2 = QtWidgets.QGridLayout(atmBridgeConfigPageWidget)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.uiMappingGroupBox = QtWidgets.QGroupBox(atmBridgeConfigPageWidget)
        self.uiMappingGroupBox.setObjectName("uiMappingGroupBox")
        self.vboxlayout = QtWidgets.QVBoxLayout(self.uiMappingGroupBox)
        self.vboxlayout.setObjectName("vboxlayout")
        self.uiMappingTreeWidget = QtWidgets.QTreeWidget(self.uiMappingGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiMappingTreeWidget.sizePolicy().hasHeightForWidth())
        self.uiMappingTreeWidget.setSizePolicy(sizePolicy)
        self.uiMappingTreeWidget.setRootIsDecorated(False)
        self.uiMappingTreeWidget.setObjectName("uiMappingTreeWidget")
        self.vboxlayout.addWidget(self.uiMappingTreeWidget)
        self.gridLayout_2.addWidget(self.uiMappingGroupBox, 0, 2, 3, 1)
        self.uiEthernetGroupBox = QtWidgets.QGroupBox(atmBridgeConfigPageWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiEthernetGroupBox.sizePolicy().hasHeightForWidth())
        self.uiEthernetGroupBox.setSizePolicy(sizePolicy)
        self.uiEthernetGroupBox.setObjectName("uiEthernetGroupBox")
        self.gridlayout = QtWidgets.QGridLayout(self.uiEthernetGroupBox)
        self.gridlayout.setObjectName("gridlayout")
        self.uiEthernetPortLabel = QtWidgets.QLabel(self.uiEthernetGroupBox)
        self.uiEthernetPortLabel.setObjectName("uiEthernetPortLabel")
        self.gridlayout.addWidget(self.uiEthernetPortLabel, 0, 0, 1, 1)
        self.uiEthernetPortSpinBox = QtWidgets.QSpinBox(self.uiEthernetGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiEthernetPortSpinBox.sizePolicy().hasHeightForWidth())
        self.uiEthernetPortSpinBox.setSizePolicy(sizePolicy)
        self.uiEthernetPortSpinBox.setMinimum(0)
        self.uiEthernetPortSpinBox.setMaximum(65535)
        self.uiEthernetPortSpinBox.setProperty("value", 1)
        self.uiEthernetPortSpinBox.setObjectName("uiEthernetPortSpinBox")
        self.gridlayout.addWidget(self.uiEthernetPortSpinBox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.uiEthernetGroupBox, 1, 0, 1, 2)
        self.uiATMGroupBox = QtWidgets.QGroupBox(atmBridgeConfigPageWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiATMGroupBox.sizePolicy().hasHeightForWidth())
        self.uiATMGroupBox.setSizePolicy(sizePolicy)
        self.uiATMGroupBox.setObjectName("uiATMGroupBox")
        self.gridlayout1 = QtWidgets.QGridLayout(self.uiATMGroupBox)
        self.gridlayout1.setObjectName("gridlayout1")
        self.uiATMPortLabel = QtWidgets.QLabel(self.uiATMGroupBox)
        self.uiATMPortLabel.setObjectName("uiATMPortLabel")
        self.gridlayout1.addWidget(self.uiATMPortLabel, 0, 0, 1, 1)
        self.uiATMPortSpinBox = QtWidgets.QSpinBox(self.uiATMGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiATMPortSpinBox.sizePolicy().hasHeightForWidth())
        self.uiATMPortSpinBox.setSizePolicy(sizePolicy)
        self.uiATMPortSpinBox.setMinimum(0)
        self.uiATMPortSpinBox.setMaximum(65535)
        self.uiATMPortSpinBox.setProperty("value", 10)
        self.uiATMPortSpinBox.setObjectName("uiATMPortSpinBox")
        self.gridlayout1.addWidget(self.uiATMPortSpinBox, 0, 1, 1, 1)
        self.uiATMVPILabel = QtWidgets.QLabel(self.uiATMGroupBox)
        self.uiATMVPILabel.setObjectName("uiATMVPILabel")
        self.gridlayout1.addWidget(self.uiATMVPILabel, 1, 0, 1, 1)
        self.uiATMVPISpinBox = QtWidgets.QSpinBox(self.uiATMGroupBox)
        self.uiATMVPISpinBox.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiATMVPISpinBox.sizePolicy().hasHeightForWidth())
        self.uiATMVPISpinBox.setSizePolicy(sizePolicy)
        self.uiATMVPISpinBox.setMinimum(0)
        self.uiATMVPISpinBox.setMaximum(65535)
        self.uiATMVPISpinBox.setSingleStep(1)
        self.uiATMVPISpinBox.setProperty("value", 0)
        self.uiATMVPISpinBox.setObjectName("uiATMVPISpinBox")
        self.gridlayout1.addWidget(self.uiATMVPISpinBox, 1, 1, 1, 1)
        self.uiATMVCILabel = QtWidgets.QLabel(self.uiATMGroupBox)
        self.uiATMVCILabel.setObjectName("uiATMVCILabel")
        self.gridlayout1.addWidget(self.uiATMVCILabel, 2, 0, 1, 1)
        self.uiATMVCISpinBox = QtWidgets.QSpinBox(self.uiATMGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiATMVCISpinBox.sizePolicy().hasHeightForWidth())
        self.uiATMVCISpinBox.setSizePolicy(sizePolicy)
        self.uiATMVCISpinBox.setMaximum(65535)
        self.uiATMVCISpinBox.setProperty("value", 100)
        self.uiATMVCISpinBox.setObjectName("uiATMVCISpinBox")
        self.gridlayout1.addWidget(self.uiATMVCISpinBox, 2, 1, 1, 1)
        self.gridLayout_2.addWidget(self.uiATMGroupBox, 2, 0, 1, 2)
        self.uiAddPushButton = QtWidgets.QPushButton(atmBridgeConfigPageWidget)
        self.uiAddPushButton.setObjectName("uiAddPushButton")
        self.gridLayout_2.addWidget(self.uiAddPushButton, 3, 0, 1, 1)
        self.uiDeletePushButton = QtWidgets.QPushButton(atmBridgeConfigPageWidget)
        self.uiDeletePushButton.setEnabled(False)
        self.uiDeletePushButton.setObjectName("uiDeletePushButton")
        self.gridLayout_2.addWidget(self.uiDeletePushButton, 3, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(371, 121, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem, 4, 0, 1, 3)
        self.uiGeneralGroupBox = QtWidgets.QGroupBox(atmBridgeConfigPageWidget)
        self.uiGeneralGroupBox.setObjectName("uiGeneralGroupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.uiGeneralGroupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.uiNameLabel = QtWidgets.QLabel(self.uiGeneralGroupBox)
        self.uiNameLabel.setObjectName("uiNameLabel")
        self.gridLayout.addWidget(self.uiNameLabel, 0, 0, 1, 1)
        self.uiNameLineEdit = QtWidgets.QLineEdit(self.uiGeneralGroupBox)
        self.uiNameLineEdit.setObjectName("uiNameLineEdit")
        self.gridLayout.addWidget(self.uiNameLineEdit, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.uiGeneralGroupBox, 0, 0, 1, 2)

        self.retranslateUi(atmBridgeConfigPageWidget)
        QtCore.QMetaObject.connectSlotsByName(atmBridgeConfigPageWidget)
        atmBridgeConfigPageWidget.setTabOrder(self.uiEthernetPortSpinBox, self.uiATMPortSpinBox)
        atmBridgeConfigPageWidget.setTabOrder(self.uiATMPortSpinBox, self.uiATMVPISpinBox)
        atmBridgeConfigPageWidget.setTabOrder(self.uiATMVPISpinBox, self.uiATMVCISpinBox)
        atmBridgeConfigPageWidget.setTabOrder(self.uiATMVCISpinBox, self.uiAddPushButton)
        atmBridgeConfigPageWidget.setTabOrder(self.uiAddPushButton, self.uiDeletePushButton)

    def retranslateUi(self, atmBridgeConfigPageWidget):
        _translate = QtCore.QCoreApplication.translate
        atmBridgeConfigPageWidget.setWindowTitle(_translate("atmBridgeConfigPageWidget", "ATM Bridge"))
        self.uiMappingGroupBox.setTitle(_translate("atmBridgeConfigPageWidget", "Mapping"))
        self.uiMappingTreeWidget.headerItem().setText(0, _translate("atmBridgeConfigPageWidget", "Ethernet Port"))
        self.uiMappingTreeWidget.headerItem().setText(1, _translate("atmBridgeConfigPageWidget", "Port:VPI:VCI"))
        self.uiEthernetGroupBox.setTitle(_translate("atmBridgeConfigPageWidget", "Ethernet side"))
        self.uiEthernetPortLabel.setText(_translate("atmBridgeConfigPageWidget", "Port:"))
        self.uiATMGroupBox.setTitle(_translate("atmBridgeConfigPageWidget", "ATM side"))
        self.uiATMPortLabel.setText(_translate("atmBridgeConfigPageWidget", "Port:"))
        self.uiATMVPILabel.setText(_translate("atmBridgeConfigPageWidget", "VPI:"))
        self.uiATMVCILabel.setText(_translate("atmBridgeConfigPageWidget", "VCI:"))
        self.uiAddPushButton.setText(_translate("atmBridgeConfigPageWidget", "&Add"))
        self.uiDeletePushButton.setText(_translate("atmBridgeConfigPageWidget", "&Delete"))
        self.uiGeneralGroupBox.setTitle(_translate("atmBridgeConfigPageWidget", "General"))
        self.uiNameLabel.setText(_translate("atmBridgeConfigPageWidget", "Name:"))



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/noplay/code/gns3/gns3-gui/gns3/modules/qemu/ui/qemu_image_wizard.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_QemuImageWizard(object):

    def setupUi(self, QemuImageWizard):
        QemuImageWizard.setObjectName("QemuImageWizard")
        QemuImageWizard.resize(535, 369)
        QemuImageWizard.setModal(True)
        QemuImageWizard.setWizardStyle(QtWidgets.QWizard.ModernStyle)
        self.uiBinaryWizardPage = QtWidgets.QWizardPage()
        self.uiBinaryWizardPage.setObjectName("uiBinaryWizardPage")
        self.gridLayout = QtWidgets.QGridLayout(self.uiBinaryWizardPage)
        self.gridLayout.setObjectName("gridLayout")
        self.uiBinaryLabel = QtWidgets.QLabel(self.uiBinaryWizardPage)
        self.uiBinaryLabel.setObjectName("uiBinaryLabel")
        self.gridLayout.addWidget(self.uiBinaryLabel, 0, 0, 1, 1)
        self.uiBinaryComboBox = QtWidgets.QComboBox(self.uiBinaryWizardPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiBinaryComboBox.sizePolicy().hasHeightForWidth())
        self.uiBinaryComboBox.setSizePolicy(sizePolicy)
        self.uiBinaryComboBox.setObjectName("uiBinaryComboBox")
        self.gridLayout.addWidget(self.uiBinaryComboBox, 0, 1, 1, 1)
        self.uiFormatLabel = QtWidgets.QLabel(self.uiBinaryWizardPage)
        self.uiFormatLabel.setObjectName("uiFormatLabel")
        self.gridLayout.addWidget(self.uiFormatLabel, 1, 0, 1, 1)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.uiFormatQcow2Radio = QtWidgets.QRadioButton(self.uiBinaryWizardPage)
        self.uiFormatQcow2Radio.setText("Qcow2")
        self.uiFormatQcow2Radio.setChecked(True)
        self.uiFormatQcow2Radio.setObjectName("uiFormatQcow2Radio")
        self.uiFormatRadios = QtWidgets.QButtonGroup(QemuImageWizard)
        self.uiFormatRadios.setObjectName("uiFormatRadios")
        self.uiFormatRadios.addButton(self.uiFormatQcow2Radio)
        self.verticalLayout_3.addWidget(self.uiFormatQcow2Radio)
        self.uiFormatQcowRadio = QtWidgets.QRadioButton(self.uiBinaryWizardPage)
        self.uiFormatQcowRadio.setText("Qcow")
        self.uiFormatQcowRadio.setObjectName("uiFormatQcowRadio")
        self.uiFormatRadios.addButton(self.uiFormatQcowRadio)
        self.verticalLayout_3.addWidget(self.uiFormatQcowRadio)
        self.uiFormatVhdRadio = QtWidgets.QRadioButton(self.uiBinaryWizardPage)
        self.uiFormatVhdRadio.setText("VHD")
        self.uiFormatVhdRadio.setObjectName("uiFormatVhdRadio")
        self.uiFormatRadios.addButton(self.uiFormatVhdRadio)
        self.verticalLayout_3.addWidget(self.uiFormatVhdRadio)
        self.uiFormatVdiRadio = QtWidgets.QRadioButton(self.uiBinaryWizardPage)
        self.uiFormatVdiRadio.setText("VDI")
        self.uiFormatVdiRadio.setObjectName("uiFormatVdiRadio")
        self.uiFormatRadios.addButton(self.uiFormatVdiRadio)
        self.verticalLayout_3.addWidget(self.uiFormatVdiRadio)
        self.uiFormatVmdkRadio = QtWidgets.QRadioButton(self.uiBinaryWizardPage)
        self.uiFormatVmdkRadio.setText("VMDK")
        self.uiFormatVmdkRadio.setObjectName("uiFormatVmdkRadio")
        self.uiFormatRadios.addButton(self.uiFormatVmdkRadio)
        self.verticalLayout_3.addWidget(self.uiFormatVmdkRadio)
        self.uiFormatRawRadio = QtWidgets.QRadioButton(self.uiBinaryWizardPage)
        self.uiFormatRawRadio.setObjectName("uiFormatRawRadio")
        self.uiFormatRadios.addButton(self.uiFormatRawRadio)
        self.verticalLayout_3.addWidget(self.uiFormatRawRadio)
        self.gridLayout.addLayout(self.verticalLayout_3, 1, 1, 1, 1)
        QemuImageWizard.addPage(self.uiBinaryWizardPage)
        self.uiQcow2OptionsWizardPage = QtWidgets.QWizardPage()
        self.uiQcow2OptionsWizardPage.setObjectName("uiQcow2OptionsWizardPage")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.uiQcow2OptionsWizardPage)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.uiSizeOptionsGroupBox = QtWidgets.QGroupBox(self.uiQcow2OptionsWizardPage)
        self.uiSizeOptionsGroupBox.setObjectName("uiSizeOptionsGroupBox")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.uiSizeOptionsGroupBox)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.uiPreallocationLabel = QtWidgets.QLabel(self.uiSizeOptionsGroupBox)
        self.uiPreallocationLabel.setObjectName("uiPreallocationLabel")
        self.gridLayout_3.addWidget(self.uiPreallocationLabel, 0, 0, 1, 1)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.uiQcow2PreallocationOffRadio = QtWidgets.QRadioButton(self.uiSizeOptionsGroupBox)
        self.uiQcow2PreallocationOffRadio.setChecked(True)
        self.uiQcow2PreallocationOffRadio.setObjectName("uiQcow2PreallocationOffRadio")
        self.uiQcow2PreallocationRadios = QtWidgets.QButtonGroup(QemuImageWizard)
        self.uiQcow2PreallocationRadios.setObjectName("uiQcow2PreallocationRadios")
        self.uiQcow2PreallocationRadios.addButton(self.uiQcow2PreallocationOffRadio)
        self.horizontalLayout_9.addWidget(self.uiQcow2PreallocationOffRadio)
        self.uiQcow2PreallocationMetadataRadio = QtWidgets.QRadioButton(self.uiSizeOptionsGroupBox)
        self.uiQcow2PreallocationMetadataRadio.setObjectName("uiQcow2PreallocationMetadataRadio")
        self.uiQcow2PreallocationRadios.addButton(self.uiQcow2PreallocationMetadataRadio)
        self.horizontalLayout_9.addWidget(self.uiQcow2PreallocationMetadataRadio)
        self.uiQcow2PreallocationFallocRadio = QtWidgets.QRadioButton(self.uiSizeOptionsGroupBox)
        self.uiQcow2PreallocationFallocRadio.setObjectName("uiQcow2PreallocationFallocRadio")
        self.uiQcow2PreallocationRadios.addButton(self.uiQcow2PreallocationFallocRadio)
        self.horizontalLayout_9.addWidget(self.uiQcow2PreallocationFallocRadio)
        self.uiQcow2PreallocationFullRadio = QtWidgets.QRadioButton(self.uiSizeOptionsGroupBox)
        self.uiQcow2PreallocationFullRadio.setObjectName("uiQcow2PreallocationFullRadio")
        self.uiQcow2PreallocationRadios.addButton(self.uiQcow2PreallocationFullRadio)
        self.horizontalLayout_9.addWidget(self.uiQcow2PreallocationFullRadio)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem)
        self.gridLayout_3.addLayout(self.horizontalLayout_9, 0, 1, 1, 1)
        self.uiClusterSizeLabel = QtWidgets.QLabel(self.uiSizeOptionsGroupBox)
        self.uiClusterSizeLabel.setObjectName("uiClusterSizeLabel")
        self.gridLayout_3.addWidget(self.uiClusterSizeLabel, 1, 0, 1, 1)
        self.uiQcow2ClusterSizeComboBox = QtWidgets.QComboBox(self.uiSizeOptionsGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiQcow2ClusterSizeComboBox.sizePolicy().hasHeightForWidth())
        self.uiQcow2ClusterSizeComboBox.setSizePolicy(sizePolicy)
        self.uiQcow2ClusterSizeComboBox.setObjectName("uiQcow2ClusterSizeComboBox")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.uiQcow2ClusterSizeComboBox.addItem("")
        self.gridLayout_3.addWidget(self.uiQcow2ClusterSizeComboBox, 1, 1, 1, 1)
        self.verticalLayout_2.addWidget(self.uiSizeOptionsGroupBox)
        self.uiRefcountsGroupBox = QtWidgets.QGroupBox(self.uiQcow2OptionsWizardPage)
        self.uiRefcountsGroupBox.setObjectName("uiRefcountsGroupBox")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.uiRefcountsGroupBox)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.uiRefcountEntrySizeLabel = QtWidgets.QLabel(self.uiRefcountsGroupBox)
        self.uiRefcountEntrySizeLabel.setObjectName("uiRefcountEntrySizeLabel")
        self.gridLayout_2.addWidget(self.uiRefcountEntrySizeLabel, 1, 0, 1, 1)
        self.uiRefcountEntrySizeComboBox = QtWidgets.QComboBox(self.uiRefcountsGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiRefcountEntrySizeComboBox.sizePolicy().hasHeightForWidth())
        self.uiRefcountEntrySizeComboBox.setSizePolicy(sizePolicy)
        self.uiRefcountEntrySizeComboBox.setObjectName("uiRefcountEntrySizeComboBox")
        self.uiRefcountEntrySizeComboBox.addItem("")
        self.uiRefcountEntrySizeComboBox.addItem("")
        self.uiRefcountEntrySizeComboBox.addItem("")
        self.uiRefcountEntrySizeComboBox.addItem("")
        self.uiRefcountEntrySizeComboBox.addItem("")
        self.uiRefcountEntrySizeComboBox.addItem("")
        self.uiRefcountEntrySizeComboBox.addItem("")
        self.uiRefcountEntrySizeComboBox.addItem("")
        self.gridLayout_2.addWidget(self.uiRefcountEntrySizeComboBox, 1, 1, 1, 1)
        self.uiLazyRefcountsCheckBox = QtWidgets.QCheckBox(self.uiRefcountsGroupBox)
        self.uiLazyRefcountsCheckBox.setTristate(False)
        self.uiLazyRefcountsCheckBox.setObjectName("uiLazyRefcountsCheckBox")
        self.gridLayout_2.addWidget(self.uiLazyRefcountsCheckBox, 0, 0, 1, 1)
        self.verticalLayout_2.addWidget(self.uiRefcountsGroupBox)
        QemuImageWizard.addPage(self.uiQcow2OptionsWizardPage)
        self.uiVhdOptionsWizardPage = QtWidgets.QWizardPage()
        self.uiVhdOptionsWizardPage.setObjectName("uiVhdOptionsWizardPage")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.uiVhdOptionsWizardPage)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.uiVhdFileSizeModeGroupBox = QtWidgets.QGroupBox(self.uiVhdOptionsWizardPage)
        self.uiVhdFileSizeModeGroupBox.setObjectName("uiVhdFileSizeModeGroupBox")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.uiVhdFileSizeModeGroupBox)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.uiVhdFileSizeModeDynamicRadio = QtWidgets.QRadioButton(self.uiVhdFileSizeModeGroupBox)
        self.uiVhdFileSizeModeDynamicRadio.setChecked(True)
        self.uiVhdFileSizeModeDynamicRadio.setObjectName("uiVhdFileSizeModeDynamicRadio")
        self.uiVhdSizeModeRadios = QtWidgets.QButtonGroup(QemuImageWizard)
        self.uiVhdSizeModeRadios.setObjectName("uiVhdSizeModeRadios")
        self.uiVhdSizeModeRadios.addButton(self.uiVhdFileSizeModeDynamicRadio)
        self.horizontalLayout_2.addWidget(self.uiVhdFileSizeModeDynamicRadio)
        self.uiVhdFileSizeModeFixedRadio = QtWidgets.QRadioButton(self.uiVhdFileSizeModeGroupBox)
        self.uiVhdFileSizeModeFixedRadio.setObjectName("uiVhdFileSizeModeFixedRadio")
        self.uiVhdSizeModeRadios.addButton(self.uiVhdFileSizeModeFixedRadio)
        self.horizontalLayout_2.addWidget(self.uiVhdFileSizeModeFixedRadio)
        spacerItem1 = QtWidgets.QSpacerItem(293, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.verticalLayout_4.addWidget(self.uiVhdFileSizeModeGroupBox)
        QemuImageWizard.addPage(self.uiVhdOptionsWizardPage)
        self.uiVdiOptionsWizardPage = QtWidgets.QWizardPage()
        self.uiVdiOptionsWizardPage.setObjectName("uiVdiOptionsWizardPage")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.uiVdiOptionsWizardPage)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.uiVdiFileSizeModeGroupBox = QtWidgets.QGroupBox(self.uiVdiOptionsWizardPage)
        self.uiVdiFileSizeModeGroupBox.setObjectName("uiVdiFileSizeModeGroupBox")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.uiVdiFileSizeModeGroupBox)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.uiVdiFileSizeModeDynamicRadio = QtWidgets.QRadioButton(self.uiVdiFileSizeModeGroupBox)
        self.uiVdiFileSizeModeDynamicRadio.setChecked(True)
        self.uiVdiFileSizeModeDynamicRadio.setObjectName("uiVdiFileSizeModeDynamicRadio")
        self.uiVdiSizeModeRadios = QtWidgets.QButtonGroup(QemuImageWizard)
        self.uiVdiSizeModeRadios.setObjectName("uiVdiSizeModeRadios")
        self.uiVdiSizeModeRadios.addButton(self.uiVdiFileSizeModeDynamicRadio)
        self.horizontalLayout_3.addWidget(self.uiVdiFileSizeModeDynamicRadio)
        self.uiVdiFileSizeModeFixedRadio = QtWidgets.QRadioButton(self.uiVdiFileSizeModeGroupBox)
        self.uiVdiFileSizeModeFixedRadio.setObjectName("uiVdiFileSizeModeFixedRadio")
        self.uiVdiSizeModeRadios.addButton(self.uiVdiFileSizeModeFixedRadio)
        self.horizontalLayout_3.addWidget(self.uiVdiFileSizeModeFixedRadio)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.verticalLayout_5.addWidget(self.uiVdiFileSizeModeGroupBox)
        QemuImageWizard.addPage(self.uiVdiOptionsWizardPage)
        self.uiVmdkOptionsWizardPage = QtWidgets.QWizardPage()
        self.uiVmdkOptionsWizardPage.setObjectName("uiVmdkOptionsWizardPage")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.uiVmdkOptionsWizardPage)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.uiVmdkAdapterTypeGroupBox = QtWidgets.QGroupBox(self.uiVmdkOptionsWizardPage)
        self.uiVmdkAdapterTypeGroupBox.setObjectName("uiVmdkAdapterTypeGroupBox")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.uiVmdkAdapterTypeGroupBox)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.uiVmdkAdapterTypeIdeRadio = QtWidgets.QRadioButton(self.uiVmdkAdapterTypeGroupBox)
        self.uiVmdkAdapterTypeIdeRadio.setChecked(True)
        self.uiVmdkAdapterTypeIdeRadio.setObjectName("uiVmdkAdapterTypeIdeRadio")
        self.uiVmdkAdapterRadios = QtWidgets.QButtonGroup(QemuImageWizard)
        self.uiVmdkAdapterRadios.setObjectName("uiVmdkAdapterRadios")
        self.uiVmdkAdapterRadios.addButton(self.uiVmdkAdapterTypeIdeRadio)
        self.horizontalLayout_4.addWidget(self.uiVmdkAdapterTypeIdeRadio)
        self.uiVmdkAdapterTypeLsiRadio = QtWidgets.QRadioButton(self.uiVmdkAdapterTypeGroupBox)
        self.uiVmdkAdapterTypeLsiRadio.setObjectName("uiVmdkAdapterTypeLsiRadio")
        self.uiVmdkAdapterRadios.addButton(self.uiVmdkAdapterTypeLsiRadio)
        self.horizontalLayout_4.addWidget(self.uiVmdkAdapterTypeLsiRadio)
        self.uiVmdkAdapterTypeBusRadio = QtWidgets.QRadioButton(self.uiVmdkAdapterTypeGroupBox)
        self.uiVmdkAdapterTypeBusRadio.setObjectName("uiVmdkAdapterTypeBusRadio")
        self.uiVmdkAdapterRadios.addButton(self.uiVmdkAdapterTypeBusRadio)
        self.horizontalLayout_4.addWidget(self.uiVmdkAdapterTypeBusRadio)
        self.uiVmdkAdapterTypeEsxRadio = QtWidgets.QRadioButton(self.uiVmdkAdapterTypeGroupBox)
        self.uiVmdkAdapterTypeEsxRadio.setObjectName("uiVmdkAdapterTypeEsxRadio")
        self.uiVmdkAdapterRadios.addButton(self.uiVmdkAdapterTypeEsxRadio)
        self.horizontalLayout_4.addWidget(self.uiVmdkAdapterTypeEsxRadio)
        spacerItem3 = QtWidgets.QSpacerItem(86, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem3)
        self.verticalLayout_6.addWidget(self.uiVmdkAdapterTypeGroupBox)
        self.uiVmdkFileSizeModeGroupBox = QtWidgets.QGroupBox(self.uiVmdkOptionsWizardPage)
        self.uiVmdkFileSizeModeGroupBox.setObjectName("uiVmdkFileSizeModeGroupBox")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.uiVmdkFileSizeModeGroupBox)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.uiVmdkFileSizeModeSparseRadio = QtWidgets.QRadioButton(self.uiVmdkFileSizeModeGroupBox)
        self.uiVmdkFileSizeModeSparseRadio.setChecked(True)
        self.uiVmdkFileSizeModeSparseRadio.setObjectName("uiVmdkFileSizeModeSparseRadio")
        self.uiVmdkSizeModeRadios = QtWidgets.QButtonGroup(QemuImageWizard)
        self.uiVmdkSizeModeRadios.setObjectName("uiVmdkSizeModeRadios")
        self.uiVmdkSizeModeRadios.addButton(self.uiVmdkFileSizeModeSparseRadio)
        self.horizontalLayout_5.addWidget(self.uiVmdkFileSizeModeSparseRadio)
        self.uiVmdkFileSizeModeFlatRadio = QtWidgets.QRadioButton(self.uiVmdkFileSizeModeGroupBox)
        self.uiVmdkFileSizeModeFlatRadio.setObjectName("uiVmdkFileSizeModeFlatRadio")
        self.uiVmdkSizeModeRadios.addButton(self.uiVmdkFileSizeModeFlatRadio)
        self.horizontalLayout_5.addWidget(self.uiVmdkFileSizeModeFlatRadio)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem4)
        self.verticalLayout_6.addWidget(self.uiVmdkFileSizeModeGroupBox)
        self.uiVmdkMiscGroupBox = QtWidgets.QGroupBox(self.uiVmdkOptionsWizardPage)
        self.uiVmdkMiscGroupBox.setObjectName("uiVmdkMiscGroupBox")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.uiVmdkMiscGroupBox)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.uiVmdkStreamOptimizedCheckBox = QtWidgets.QCheckBox(self.uiVmdkMiscGroupBox)
        self.uiVmdkStreamOptimizedCheckBox.setObjectName("uiVmdkStreamOptimizedCheckBox")
        self.horizontalLayout_6.addWidget(self.uiVmdkStreamOptimizedCheckBox)
        self.uiVmdkSplit2gCheckBox = QtWidgets.QCheckBox(self.uiVmdkMiscGroupBox)
        self.uiVmdkSplit2gCheckBox.setObjectName("uiVmdkSplit2gCheckBox")
        self.horizontalLayout_6.addWidget(self.uiVmdkSplit2gCheckBox)
        self.uiVmdkZeroedGrainCheckBox = QtWidgets.QCheckBox(self.uiVmdkMiscGroupBox)
        self.uiVmdkZeroedGrainCheckBox.setObjectName("uiVmdkZeroedGrainCheckBox")
        self.horizontalLayout_6.addWidget(self.uiVmdkZeroedGrainCheckBox)
        spacerItem5 = QtWidgets.QSpacerItem(36, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem5)
        self.verticalLayout_6.addWidget(self.uiVmdkMiscGroupBox)
        QemuImageWizard.addPage(self.uiVmdkOptionsWizardPage)
        self.uiSizeAndLocationWizardPage = QtWidgets.QWizardPage()
        self.uiSizeAndLocationWizardPage.setObjectName("uiSizeAndLocationWizardPage")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.uiSizeAndLocationWizardPage)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.uiLocationLabel = QtWidgets.QLabel(self.uiSizeAndLocationWizardPage)
        self.uiLocationLabel.setObjectName("uiLocationLabel")
        self.gridLayout_4.addWidget(self.uiLocationLabel, 0, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.uiLocationLineEdit = QtWidgets.QLineEdit(self.uiSizeAndLocationWizardPage)
        self.uiLocationLineEdit.setObjectName("uiLocationLineEdit")
        self.horizontalLayout.addWidget(self.uiLocationLineEdit)
        self.uiLocationBrowseToolButton = QtWidgets.QToolButton(self.uiSizeAndLocationWizardPage)
        self.uiLocationBrowseToolButton.setObjectName("uiLocationBrowseToolButton")
        self.horizontalLayout.addWidget(self.uiLocationBrowseToolButton)
        self.gridLayout_4.addLayout(self.horizontalLayout, 0, 1, 1, 1)
        self.uiSizeLabel = QtWidgets.QLabel(self.uiSizeAndLocationWizardPage)
        self.uiSizeLabel.setObjectName("uiSizeLabel")
        self.gridLayout_4.addWidget(self.uiSizeLabel, 1, 0, 1, 1)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.uiSizeSpinBox = QtWidgets.QSpinBox(self.uiSizeAndLocationWizardPage)
        self.uiSizeSpinBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.UpDownArrows)
        self.uiSizeSpinBox.setMinimum(0)
        self.uiSizeSpinBox.setMaximum(2000000)
        self.uiSizeSpinBox.setSingleStep(1000)
        self.uiSizeSpinBox.setProperty("value", 30000)
        self.uiSizeSpinBox.setProperty("showGroupSeparator", True)
        self.uiSizeSpinBox.setObjectName("uiSizeSpinBox")
        self.horizontalLayout_7.addWidget(self.uiSizeSpinBox)
        self.gridLayout_4.addLayout(self.horizontalLayout_7, 1, 1, 1, 1)
        QemuImageWizard.addPage(self.uiSizeAndLocationWizardPage)

        self.retranslateUi(QemuImageWizard)
        self.uiVmdkStreamOptimizedCheckBox.toggled['bool'].connect(self.uiVmdkFileSizeModeFlatRadio.setDisabled)
        self.uiVmdkStreamOptimizedCheckBox.toggled['bool'].connect(self.uiVmdkSplit2gCheckBox.setDisabled)
        QtCore.QMetaObject.connectSlotsByName(QemuImageWizard)

    def retranslateUi(self, QemuImageWizard):
        _translate = QtCore.QCoreApplication.translate
        QemuImageWizard.setWindowTitle(_translate("QemuImageWizard", "Qemu image creator"))
        self.uiBinaryWizardPage.setTitle(_translate("QemuImageWizard", "Binary and format"))
        self.uiBinaryWizardPage.setSubTitle(_translate("QemuImageWizard", "Please select a qemu-img binary, and the format for your new image."))
        self.uiBinaryLabel.setText(_translate("QemuImageWizard", "Qemu-img binary:"))
        self.uiFormatLabel.setText(_translate("QemuImageWizard", "Image format:"))
        self.uiFormatQcow2Radio.setToolTip(_translate("QemuImageWizard", "Qcow2 is the current Qemu format, supporting many special features."))
        self.uiFormatQcowRadio.setToolTip(_translate("QemuImageWizard", "Qcow is a legacy Qemu format that is also supported by VirtualBox."))
        self.uiFormatVhdRadio.setToolTip(_translate("QemuImageWizard", "VHD is the format used by Microsoft VirtualPC, and is also supported by Qemu and VirtualBox.\n"
                                                    "On Windows 7 and above, it can be mounted on the host PC."))
        self.uiFormatVdiRadio.setToolTip(_translate("QemuImageWizard", "VDI is the native format of VirtualBox"))
        self.uiFormatVmdkRadio.setToolTip(_translate("QemuImageWizard", "VMDK is the native format for VMware and is also supported by Qemu and VirtualBox."))
        self.uiFormatRawRadio.setToolTip(_translate("QemuImageWizard", "Raw image files represent the actual data on the image, with zero special features.\n"
                                                    "It can easily be converted to various other formats by various utilities, making it the most portable format."))
        self.uiFormatRawRadio.setText(_translate("QemuImageWizard", "Raw"))
        self.uiQcow2OptionsWizardPage.setTitle(_translate("QemuImageWizard", "Qcow2 options"))
        self.uiSizeOptionsGroupBox.setTitle(_translate("QemuImageWizard", "Size options"))
        self.uiPreallocationLabel.setText(_translate("QemuImageWizard", "Preallocation:"))
        self.uiQcow2PreallocationOffRadio.setToolTip(_translate("QemuImageWizard", "The file only takes as much space from the host as needed. The VM will still see the full capacity you specify."))
        self.uiQcow2PreallocationOffRadio.setText(_translate("QemuImageWizard", "off"))
        self.uiQcow2PreallocationMetadataRadio.setToolTip(_translate("QemuImageWizard", "Same as \"off\", but preallocates enough space to hold any potenial metadata for the HDD.\n"
                                                                     "This improves performance when the image file needs to grow."))
        self.uiQcow2PreallocationMetadataRadio.setText(_translate("QemuImageWizard", "metadata"))
        self.uiQcow2PreallocationFallocRadio.setToolTip(_translate("QemuImageWizard", "Same as \"full\", but uses C\'s posix_fallocate() if available on the host, instead of zero filling the file."))
        self.uiQcow2PreallocationFallocRadio.setText(_translate("QemuImageWizard", "falloc"))
        self.uiQcow2PreallocationFullRadio.setToolTip(_translate("QemuImageWizard", "The file will start off at the full size you specify.\n"
                                                                 "Free space will be zero filled."))
        self.uiQcow2PreallocationFullRadio.setText(_translate("QemuImageWizard", "full"))
        self.uiClusterSizeLabel.setText(_translate("QemuImageWizard", "Cluster size:"))
        self.uiQcow2ClusterSizeComboBox.setItemText(0, _translate("QemuImageWizard", "<default>"))
        self.uiQcow2ClusterSizeComboBox.setItemText(1, _translate("QemuImageWizard", "512"))
        self.uiQcow2ClusterSizeComboBox.setItemText(2, _translate("QemuImageWizard", "1k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(3, _translate("QemuImageWizard", "2k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(4, _translate("QemuImageWizard", "4k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(5, _translate("QemuImageWizard", "8k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(6, _translate("QemuImageWizard", "16k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(7, _translate("QemuImageWizard", "32k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(8, _translate("QemuImageWizard", "64k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(9, _translate("QemuImageWizard", "128k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(10, _translate("QemuImageWizard", "256k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(11, _translate("QemuImageWizard", "512k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(12, _translate("QemuImageWizard", "1024k"))
        self.uiQcow2ClusterSizeComboBox.setItemText(13, _translate("QemuImageWizard", "2048k"))
        self.uiRefcountsGroupBox.setTitle(_translate("QemuImageWizard", "Refcounts"))
        self.uiRefcountEntrySizeLabel.setText(_translate("QemuImageWizard", "Refcount entry size:"))
        self.uiRefcountEntrySizeComboBox.setItemText(0, _translate("QemuImageWizard", "<default>"))
        self.uiRefcountEntrySizeComboBox.setItemText(1, _translate("QemuImageWizard", "1"))
        self.uiRefcountEntrySizeComboBox.setItemText(2, _translate("QemuImageWizard", "2"))
        self.uiRefcountEntrySizeComboBox.setItemText(3, _translate("QemuImageWizard", "4"))
        self.uiRefcountEntrySizeComboBox.setItemText(4, _translate("QemuImageWizard", "8"))
        self.uiRefcountEntrySizeComboBox.setItemText(5, _translate("QemuImageWizard", "16"))
        self.uiRefcountEntrySizeComboBox.setItemText(6, _translate("QemuImageWizard", "32"))
        self.uiRefcountEntrySizeComboBox.setItemText(7, _translate("QemuImageWizard", "64"))
        self.uiLazyRefcountsCheckBox.setText(_translate("QemuImageWizard", "Lazy refcounts"))
        self.uiVhdOptionsWizardPage.setTitle(_translate("QemuImageWizard", "VHD options"))
        self.uiVhdFileSizeModeGroupBox.setTitle(_translate("QemuImageWizard", "Image file sizing mode"))
        self.uiVhdFileSizeModeDynamicRadio.setToolTip(_translate("QemuImageWizard", "The file only takes as much space from the host as needed. The VM will still see the full capacity you specify."))
        self.uiVhdFileSizeModeDynamicRadio.setText(_translate("QemuImageWizard", "Dynamic"))
        self.uiVhdFileSizeModeFixedRadio.setToolTip(_translate("QemuImageWizard", "The file will start off at the full size you specify."))
        self.uiVhdFileSizeModeFixedRadio.setText(_translate("QemuImageWizard", "Fixed"))
        self.uiVdiOptionsWizardPage.setTitle(_translate("QemuImageWizard", "VDI options"))
        self.uiVdiFileSizeModeGroupBox.setTitle(_translate("QemuImageWizard", "Image file sizing mode"))
        self.uiVdiFileSizeModeDynamicRadio.setToolTip(_translate("QemuImageWizard", "The file only takes as much space from the host as needed. The VM will still see the full capacity you specify."))
        self.uiVdiFileSizeModeDynamicRadio.setText(_translate("QemuImageWizard", "Dynamic"))
        self.uiVdiFileSizeModeFixedRadio.setToolTip(_translate("QemuImageWizard", "The file will start off at the full size you specify."))
        self.uiVdiFileSizeModeFixedRadio.setText(_translate("QemuImageWizard", "Fixed"))
        self.uiVmdkOptionsWizardPage.setTitle(_translate("QemuImageWizard", "VMDK options"))
        self.uiVmdkAdapterTypeGroupBox.setTitle(_translate("QemuImageWizard", "Adapter type"))
        self.uiVmdkAdapterTypeIdeRadio.setText(_translate("QemuImageWizard", "IDE"))
        self.uiVmdkAdapterTypeLsiRadio.setText(_translate("QemuImageWizard", "LSI Logic"))
        self.uiVmdkAdapterTypeBusRadio.setText(_translate("QemuImageWizard", "BusLogic"))
        self.uiVmdkAdapterTypeEsxRadio.setText(_translate("QemuImageWizard", "Legacy (ESX)"))
        self.uiVmdkFileSizeModeGroupBox.setTitle(_translate("QemuImageWizard", "Image file sizing mode"))
        self.uiVmdkFileSizeModeSparseRadio.setToolTip(_translate("QemuImageWizard", "The file only takes as much space from the host as needed. The VM will still see the full capacity you specify."))
        self.uiVmdkFileSizeModeSparseRadio.setText(_translate("QemuImageWizard", "Sparse"))
        self.uiVmdkFileSizeModeFlatRadio.setToolTip(_translate("QemuImageWizard", "The file will start off at the full size you specify."))
        self.uiVmdkFileSizeModeFlatRadio.setText(_translate("QemuImageWizard", "Flat"))
        self.uiVmdkMiscGroupBox.setTitle(_translate("QemuImageWizard", "Misc"))
        self.uiVmdkStreamOptimizedCheckBox.setText(_translate("QemuImageWizard", "Stream optimized"))
        self.uiVmdkSplit2gCheckBox.setText(_translate("QemuImageWizard", "Split every 2 GiB"))
        self.uiVmdkZeroedGrainCheckBox.setText(_translate("QemuImageWizard", "Zeroed grain"))
        self.uiSizeAndLocationWizardPage.setTitle(_translate("QemuImageWizard", "Size and location"))
        self.uiLocationLabel.setText(_translate("QemuImageWizard", "File location:"))
        self.uiLocationBrowseToolButton.setText(_translate("QemuImageWizard", "Browse"))
        self.uiSizeLabel.setText(_translate("QemuImageWizard", "Disk size:"))
        self.uiSizeSpinBox.setSuffix(_translate("QemuImageWizard", " MiB"))



# -*- coding: utf-8 -*-
#
# Copyright (C) 2015 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Interface for NAT NIOs.
"""

from .nio import NIO


class NIONAT(NIO):

    """
    NAT NIO.
    """

    def __init__(self, identifier):

        super().__init__()
        self._identifier = identifier

    def __str__(self):

        return "NIO_NAT"

    def identifier(self):
        """
        Returns the identifier used by this NIO.

        :returns: the identifier
        """

        return self._identifier



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/modules/iou/ui/iou_device_preferences_page.ui'
#
# Created: Sun Mar 27 11:39:22 2016
#      by: PyQt5 UI code generator 5.2.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_IOUDevicePreferencesPageWidget(object):
    def setupUi(self, IOUDevicePreferencesPageWidget):
        IOUDevicePreferencesPageWidget.setObjectName("IOUDevicePreferencesPageWidget")
        IOUDevicePreferencesPageWidget.resize(559, 515)
        IOUDevicePreferencesPageWidget.setAccessibleDescription("")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(IOUDevicePreferencesPageWidget)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.splitter = QtWidgets.QSplitter(IOUDevicePreferencesPageWidget)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.uiIOUDevicesTreeWidget = QtWidgets.QTreeWidget(self.splitter)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiIOUDevicesTreeWidget.sizePolicy().hasHeightForWidth())
        self.uiIOUDevicesTreeWidget.setSizePolicy(sizePolicy)
        self.uiIOUDevicesTreeWidget.setMaximumSize(QtCore.QSize(160, 16777215))
        font = QtGui.QFont()
        font.setPointSize(11)
        font.setBold(True)
        font.setWeight(75)
        self.uiIOUDevicesTreeWidget.setFont(font)
        self.uiIOUDevicesTreeWidget.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.uiIOUDevicesTreeWidget.setIconSize(QtCore.QSize(32, 32))
        self.uiIOUDevicesTreeWidget.setRootIsDecorated(False)
        self.uiIOUDevicesTreeWidget.setObjectName("uiIOUDevicesTreeWidget")
        self.uiIOUDevicesTreeWidget.headerItem().setText(0, "1")
        self.uiIOUDevicesTreeWidget.header().setVisible(False)
        self.widget = QtWidgets.QWidget(self.splitter)
        self.widget.setObjectName("widget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.widget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.uiIOUDeviceInfoTreeWidget = QtWidgets.QTreeWidget(self.widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiIOUDeviceInfoTreeWidget.sizePolicy().hasHeightForWidth())
        self.uiIOUDeviceInfoTreeWidget.setSizePolicy(sizePolicy)
        self.uiIOUDeviceInfoTreeWidget.setIndentation(10)
        self.uiIOUDeviceInfoTreeWidget.setAllColumnsShowFocus(True)
        self.uiIOUDeviceInfoTreeWidget.setObjectName("uiIOUDeviceInfoTreeWidget")
        self.uiIOUDeviceInfoTreeWidget.header().setVisible(False)
        self.verticalLayout.addWidget(self.uiIOUDeviceInfoTreeWidget)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.uiNewIOUDevicePushButton = QtWidgets.QPushButton(self.widget)
        self.uiNewIOUDevicePushButton.setObjectName("uiNewIOUDevicePushButton")
        self.horizontalLayout_5.addWidget(self.uiNewIOUDevicePushButton)
        self.uiEditIOUDevicePushButton = QtWidgets.QPushButton(self.widget)
        self.uiEditIOUDevicePushButton.setEnabled(False)
        self.uiEditIOUDevicePushButton.setObjectName("uiEditIOUDevicePushButton")
        self.horizontalLayout_5.addWidget(self.uiEditIOUDevicePushButton)
        self.uiDeleteIOUDevicePushButton = QtWidgets.QPushButton(self.widget)
        self.uiDeleteIOUDevicePushButton.setEnabled(False)
        self.uiDeleteIOUDevicePushButton.setObjectName("uiDeleteIOUDevicePushButton")
        self.horizontalLayout_5.addWidget(self.uiDeleteIOUDevicePushButton)
        self.verticalLayout.addLayout(self.horizontalLayout_5)
        self.verticalLayout_2.addWidget(self.splitter)

        self.retranslateUi(IOUDevicePreferencesPageWidget)
        QtCore.QMetaObject.connectSlotsByName(IOUDevicePreferencesPageWidget)
        IOUDevicePreferencesPageWidget.setTabOrder(self.uiNewIOUDevicePushButton, self.uiDeleteIOUDevicePushButton)

    def retranslateUi(self, IOUDevicePreferencesPageWidget):
        _translate = QtCore.QCoreApplication.translate
        IOUDevicePreferencesPageWidget.setWindowTitle(_translate("IOUDevicePreferencesPageWidget", "IOU Devices"))
        IOUDevicePreferencesPageWidget.setAccessibleName(_translate("IOUDevicePreferencesPageWidget", "IOU Device templates"))
        self.uiIOUDeviceInfoTreeWidget.headerItem().setText(0, _translate("IOUDevicePreferencesPageWidget", "1"))
        self.uiIOUDeviceInfoTreeWidget.headerItem().setText(1, _translate("IOUDevicePreferencesPageWidget", "2"))
        self.uiNewIOUDevicePushButton.setText(_translate("IOUDevicePreferencesPageWidget", "&New"))
        self.uiEditIOUDevicePushButton.setText(_translate("IOUDevicePreferencesPageWidget", "&Edit"))
        self.uiDeleteIOUDevicePushButton.setText(_translate("IOUDevicePreferencesPageWidget", "&Delete"))




#!/usr/bin/env python
#
# Copyright (C) 2015 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import json
import copy
import os
import collections


class ApplianceError(Exception):
    pass


class Appliance(collections.Mapping):

    def __init__(self, registry, path):
        """
        :params registry: Instance of the registry where images are located
        :params path: Path of the appliance file on disk
        """
        self._registry = registry

        try:
            with open(path, encoding="utf-8") as f:
                self._appliance = json.load(f)
        except (OSError, ValueError) as e:
            raise ApplianceError("Could not read appliance {}: {}".format(os.path.abspath(path), str(e)))
        self._check_config()
        self._resolve_version()

    def _check_config(self):
        """
        :param appliance: Sanity check on the appliance configuration
        """
        if "registry_version" not in self._appliance:
            raise ApplianceError("Invalid appliance configuration please report the issue on https://github.com/GNS3/gns3-registry")
        if self._appliance["registry_version"] > 3:
            raise ApplianceError("Please update GNS3 in order to install this appliance")

    def __getitem__(self, key):
        return self._appliance.__getitem__(key)

    def __iter__(self):
        return self._appliance.__iter__()

    def __len__(self):
        return self._appliance.__len__()

    def _resolve_version(self):
        """
        Replace image field in versions by their the complete information from images
        """

        if "versions" not in self._appliance:
            return

        for version in self._appliance["versions"]:
            for image_type, filename in version["images"].items():

                found = False

                for file in self._appliance["images"]:
                    file = copy.copy(file)

                    if "idlepc" in version:
                        file["idlepc"] = version["idlepc"]

                    if "/" in filename:
                        parent = filename.split("/")[0]
                        name = filename.split("/")[-1:][0]
                        filename = os.path.join(parent, name)
                    else:
                        parent = filename

                    if file["filename"] == parent:
                        file["filename"] = filename
                        version["images"][image_type] = file
                        found = True
                        break

                if not found:
                    raise ApplianceError("Broken appliance missing file {} for version {}".format(filename, version["name"]))

    def create_new_version(self, version_name):
        """
        Duplicate a version in order to create a new version
        """
        ref = self._appliance["versions"][0]
        new_version= {'name': version_name}
        new_version['images'] = {}

        for disk_type in ref['images']:
            filename = ref['images'][disk_type]['filename']
            filename = filename.replace(ref['images'][disk_type]['version'], version_name)
            new_version['images'][disk_type] = {'filename': filename, 'version': version_name}
        self._appliance['versions'].append(new_version)

    def search_images_for_version(self, version_name):
        """
        Search on disk the images required by this version.
        And keep only the require images in the images fields. Add to the images
        their disk type and path.

        :param version_name: Version name
        :returns: Appliance with only require images
        """

        found = False
        appliance = copy.deepcopy(self._appliance)
        for version in appliance["versions"]:
            if version["name"] == version_name:
                appliance["images"] = []
                for image_type, image in version["images"].items():
                    image["type"] = image_type

                    img = self._registry.search_image_file(image["filename"], image.get("md5sum"), image.get("filesize"))
                    if img is None:
                        if "md5sum" in image:
                            raise ApplianceError("File {} with checksum {} not found for {}".format(image["filename"], image["md5sum"], appliance["name"]))
                        else:
                            raise ApplianceError("File {} not found for {}".format(image["filename"], appliance["name"]))

                    image["path"] = img.path

                    if "md5sum" not in image:
                        image["md5sum"] = img.md5sum
                        image["filesize"] = img.filesize

                    appliance["images"].append(image)
                    found = True
                appliance["name"] = "{} {}".format(appliance["name"], version_name)
                break

        if not found:
            raise ApplianceError("Version {} not found for {}".format(version_name, appliance["name"]))

        return appliance

    def copy(self):
        """
        Get a copy of the appliance
        """
        return copy.deepcopy(self._appliance)

    def is_version_installable(self, version):
        """
        Search on disk if a version is available for this appliance

        :params version: Version name
        :returns: Boolean true if installable
        """

        try:
            self.search_images_for_version(version)
            return True
        except ApplianceError:
            return False

    def image_dir_name(self):
        """
        :returns: The name of directory where image should be located
        """
        if "qemu" in self._appliance:
            return "QEMU"
        if "iou" in self._appliance:
            return "IOU"
        return "IOS"




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2014 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
import os

# Try to install updates & restart application if an update is installed
try:
    import gns3.update_manager
    if gns3.update_manager.UpdateManager().installDownloadedUpdates():
        print("Update installed restart the application")
        python = sys.executable
        os.execl(python, *sys.argv)
except Exception as e:
    print("Fail update installation: {}".format(str(e)))


# WARNING
# Due to buggy user machines we choose to put this as the first loading modules
# otherwise the egg cache is initialized in his standard location and
# if is not writetable the application crash. It's the user fault
# because one day the user as used sudo to run an egg and break his
# filesystem permissions, but it's a common mistake.
from gns3.utils.get_resource import get_resource


import datetime
import traceback
import time
import locale
import argparse
import signal
import psutil

try:
    from gns3.qt import QtCore, QtGui, QtWidgets
except ImportError:
    raise SystemExit("Can't import Qt modules: Qt and/or PyQt is probably not installed correctly...")
from gns3.main_window import MainWindow

from gns3.logger import init_logger
from gns3.crash_report import CrashReport
from gns3.local_config import LocalConfig
from gns3.application import Application
from gns3.utils import parse_version


import logging
log = logging.getLogger(__name__)

from gns3.version import __version__


def locale_check():
    """
    Checks if this application runs with a correct locale (i.e. supports UTF-8 encoding) and attempt to fix
    if this is not the case.

    This is to prevent UnicodeEncodeError with unicode paths when using standard library I/O operation
    methods (e.g. os.stat() or os.path.*) which rely on the system or user locale.

    More information can be found there: http://seasonofcode.com/posts/unicode-i-o-and-locales-in-python.html
    or there: http://robjwells.com/post/61198832297/get-your-us-ascii-out-of-my-face
    """

    # no need to check on Windows or when frozen
    if sys.platform.startswith("win") or hasattr(sys, "frozen"):
        return

    language = encoding = None
    try:
        language, encoding = locale.getlocale()
    except ValueError as e:
        log.error("could not determine the current locale: {}".format(e))
    if not language and not encoding:
        try:
            log.warn("could not find a default locale, switching to C.UTF-8...")
            locale.setlocale(locale.LC_ALL, ("C", "UTF-8"))
        except locale.Error as e:
            log.error("could not switch to the C.UTF-8 locale: {}".format(e))
            raise SystemExit
    elif encoding != "UTF-8":
        log.warn("your locale {}.{} encoding is not UTF-8, switching to the UTF-8 version...".format(language, encoding))
        try:
            locale.setlocale(locale.LC_ALL, (language, "UTF-8"))
        except locale.Error as e:
            log.error("could not set an UTF-8 encoding for the {} locale: {}".format(language, e))
            raise SystemExit
    else:
        log.info("current locale is {}.{}".format(language, encoding))


def main():
    """
    Entry point for GNS3 GUI.
    """

    # Sometimes (for example at first launch) the OSX app service launcher add
    # an extra argument starting with -psn_. We filter it
    if sys.platform.startswith("darwin"):
        sys.argv = [a for a in sys.argv if not a.startswith("-psn_")]

    parser = argparse.ArgumentParser()
    parser.add_argument("project", help="load a GNS3 project (.gns3)", metavar="path", nargs="?")
    parser.add_argument("--version", help="show the version", action="version", version=__version__)
    parser.add_argument("--debug", help="print out debug messages", action="store_true", default=False)
    parser.add_argument("--config", help="Configuration file")
    options = parser.parse_args()
    exception_file_path = "exceptions.log"

    if options.config:
        LocalConfig.instance(config_file=options.config)
    else:
        LocalConfig.instance()

    if hasattr(sys, "frozen"):
        # We add to the path where the OS search executable our binary location starting by GNS3
        # packaged binary
        frozen_dir = os.path.dirname(os.path.abspath(sys.executable))
        if sys.platform.startswith("darwin"):
            frozen_dirs = [
                frozen_dir,
                os.path.normpath(os.path.join(frozen_dir, '..', 'Resources'))
            ]
        elif sys.platform.startswith("win"):
            frozen_dirs = [
                frozen_dir,
                os.path.normpath(os.path.join(frozen_dir, 'dynamips')),
                os.path.normpath(os.path.join(frozen_dir, 'vpcs'))
            ]

        os.environ["PATH"] = os.pathsep.join(frozen_dirs) + os.pathsep + os.environ.get("PATH", "")

        if options.project:
            options.project = os.path.abspath(options.project)
            os.chdir(frozen_dir)

    def exceptionHook(exception, value, tb):

        if exception == KeyboardInterrupt:
            sys.exit(0)

        lines = traceback.format_exception(exception, value, tb)
        print("****** Exception detected, traceback information saved in {} ******".format(exception_file_path))
        print("\nPLEASE REPORT ON https://www.gns3.com\n")
        print("".join(lines))
        try:
            curdate = time.strftime("%d %b %Y %H:%M:%S")
            logfile = open(exception_file_path, "a", encoding="utf-8")
            logfile.write("=== GNS3 {} traceback on {} ===\n".format(__version__, curdate))
            logfile.write("".join(lines))
            logfile.close()
        except OSError as e:
            print("Could not save traceback to {}: {}".format(os.path.normpath(exception_file_path), e))

        if not sys.stdout.isatty():
            # if stdout is not a tty (redirected to the console view),
            # then print the exception on stderr too.
            print("".join(lines), file=sys.stderr)

        if exception is MemoryError:
            print("YOUR SYSTEM IS OUT OF MEMORY!")
        else:
            CrashReport.instance().captureException(exception, value, tb)

    # catch exceptions to write them in a file
    sys.excepthook = exceptionHook

    current_year = datetime.date.today().year
    print("GNS3 GUI version {}".format(__version__))
    print("Copyright (c) 2007-{} GNS3 Technologies Inc.".format(current_year))

    # we only support Python 3 version >= 3.4
    if sys.version_info < (3, 4):
        raise SystemExit("Python 3.4 or higher is required")

    if parse_version(QtCore.QT_VERSION_STR) < parse_version("5.0.0"):
        raise SystemExit("Requirement is PyQt5 version 5.0.0 or higher, got version {}".format(QtCore.QT_VERSION_STR))

    if parse_version(psutil.__version__) < parse_version("2.2.1"):
        raise SystemExit("Requirement is psutil version 2.2.1 or higher, got version {}".format(psutil.__version__))

    # check for the correct locale
    # (UNIX/Linux only)
    locale_check()

    try:
        os.getcwd()
    except FileNotFoundError:
        log.critical("the current working directory doesn't exist")
        return

    # always use the INI format on Windows and OSX (because we don't like the registry and plist files)
    if sys.platform.startswith('win') or sys.platform.startswith('darwin'):
        QtCore.QSettings.setDefaultFormat(QtCore.QSettings.IniFormat)

    if sys.platform.startswith('win') and hasattr(sys, "frozen"):
        try:
            import win32console
            import win32con
            import win32gui
        except ImportError:
            raise SystemExit("Python for Windows extensions must be installed.")

        if not options.debug:
            try:
                # hide the console
                console_window = win32console.GetConsoleWindow()
                win32gui.ShowWindow(console_window, win32con.SW_HIDE)
            except win32console.error as e:
                print("warning: could not allocate console: {}".format(e))

    global app
    app = Application(sys.argv)

    # save client logging info to a file
    logfile = os.path.join(LocalConfig.configDirectory(), "gns3_gui.log")

    # on debug enable logging to stdout
    if options.debug:
        root_logger = init_logger(logging.DEBUG, logfile)
    else:
        root_logger = init_logger(logging.INFO, logfile)

    # update the exception file path to have it in the same directory as the settings file.
    exception_file_path = os.path.join(LocalConfig.configDirectory(), exception_file_path)

    global mainwindow
    mainwindow = MainWindow()

    # On OSX we can receive the file to open from a system event
    # loadPath is smart and will load only if a path is present
    mainwindow.ready_signal.connect(lambda: mainwindow.loadPath(app.open_file_at_startup))
    mainwindow.ready_signal.connect(lambda: mainwindow.loadPath(options.project))
    app.file_open_signal.connect(lambda path: mainwindow.loadPath(path))

    # Manage Ctrl + C or kill command
    def sigint_handler(*args):
        log.info("Signal received exiting the application")
        mainwindow.setSoftExit(False)
        app.closeAllWindows()
    orig_sigint = signal.signal(signal.SIGINT, sigint_handler)
    orig_sigterm = signal.signal(signal.SIGTERM, sigint_handler)

    mainwindow.show()

    exit_code = app.exec_()

    signal.signal(signal.SIGINT, orig_sigint)
    signal.signal(signal.SIGTERM, orig_sigterm)


    delattr(MainWindow, "_instance")

    # We force deleting the app object otherwise it's segfault on Fedora
    del app
    # We force a full garbage collect before exit
    # for unknow reason otherwise Qt Segfault on OSX in some
    # conditions
    import gc
    gc.collect()

    sys.exit(exit_code)

if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/modules/docker/ui/docker_vm_wizard.ui'
#
# Created: Sun May  8 10:33:23 2016
#      by: PyQt5 UI code generator 5.2.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_DockerVMWizard(object):
    def setupUi(self, DockerVMWizard):
        DockerVMWizard.setObjectName("DockerVMWizard")
        DockerVMWizard.resize(638, 437)
        DockerVMWizard.setModal(True)
        self.uiServerWizardPage = QtWidgets.QWizardPage()
        self.uiServerWizardPage.setObjectName("uiServerWizardPage")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.uiServerWizardPage)
        self.verticalLayout.setObjectName("verticalLayout")
        self.uiServerTypeGroupBox = QtWidgets.QGroupBox(self.uiServerWizardPage)
        self.uiServerTypeGroupBox.setObjectName("uiServerTypeGroupBox")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.uiServerTypeGroupBox)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.uiRemoteRadioButton = QtWidgets.QRadioButton(self.uiServerTypeGroupBox)
        self.uiRemoteRadioButton.setChecked(True)
        self.uiRemoteRadioButton.setObjectName("uiRemoteRadioButton")
        self.verticalLayout_5.addWidget(self.uiRemoteRadioButton)
        self.uiVMRadioButton = QtWidgets.QRadioButton(self.uiServerTypeGroupBox)
        self.uiVMRadioButton.setObjectName("uiVMRadioButton")
        self.verticalLayout_5.addWidget(self.uiVMRadioButton)
        self.uiLocalRadioButton = QtWidgets.QRadioButton(self.uiServerTypeGroupBox)
        self.uiLocalRadioButton.setObjectName("uiLocalRadioButton")
        self.verticalLayout_5.addWidget(self.uiLocalRadioButton)
        self.verticalLayout.addWidget(self.uiServerTypeGroupBox)
        self.uiRemoteServersGroupBox = QtWidgets.QGroupBox(self.uiServerWizardPage)
        self.uiRemoteServersGroupBox.setObjectName("uiRemoteServersGroupBox")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.uiRemoteServersGroupBox)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.uiRemoteServersLabel = QtWidgets.QLabel(self.uiRemoteServersGroupBox)
        self.uiRemoteServersLabel.setObjectName("uiRemoteServersLabel")
        self.gridLayout_7.addWidget(self.uiRemoteServersLabel, 0, 0, 1, 1)
        self.uiRemoteServersComboBox = QtWidgets.QComboBox(self.uiRemoteServersGroupBox)
        self.uiRemoteServersComboBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiRemoteServersComboBox.sizePolicy().hasHeightForWidth())
        self.uiRemoteServersComboBox.setSizePolicy(sizePolicy)
        self.uiRemoteServersComboBox.setObjectName("uiRemoteServersComboBox")
        self.gridLayout_7.addWidget(self.uiRemoteServersComboBox, 0, 1, 1, 1)
        self.verticalLayout.addWidget(self.uiRemoteServersGroupBox)
        DockerVMWizard.addPage(self.uiServerWizardPage)
        self.uiImageWizardPage = QtWidgets.QWizardPage()
        self.uiImageWizardPage.setObjectName("uiImageWizardPage")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.uiImageWizardPage)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.uiExistingImageRadioButton = QtWidgets.QRadioButton(self.uiImageWizardPage)
        self.uiExistingImageRadioButton.setObjectName("uiExistingImageRadioButton")
        self.horizontalLayout_3.addWidget(self.uiExistingImageRadioButton)
        self.uiNewImageRadioButton = QtWidgets.QRadioButton(self.uiImageWizardPage)
        self.uiNewImageRadioButton.setObjectName("uiNewImageRadioButton")
        self.horizontalLayout_3.addWidget(self.uiNewImageRadioButton)
        self.verticalLayout_3.addLayout(self.horizontalLayout_3)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.uiImageListLabel = QtWidgets.QLabel(self.uiImageWizardPage)
        self.uiImageListLabel.setObjectName("uiImageListLabel")
        self.gridLayout.addWidget(self.uiImageListLabel, 0, 0, 1, 1)
        self.uiImageListComboBox = QtWidgets.QComboBox(self.uiImageWizardPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiImageListComboBox.sizePolicy().hasHeightForWidth())
        self.uiImageListComboBox.setSizePolicy(sizePolicy)
        self.uiImageListComboBox.setObjectName("uiImageListComboBox")
        self.gridLayout.addWidget(self.uiImageListComboBox, 0, 1, 1, 1)
        self.uiImageLineEdit = QtWidgets.QLineEdit(self.uiImageWizardPage)
        self.uiImageLineEdit.setObjectName("uiImageLineEdit")
        self.gridLayout.addWidget(self.uiImageLineEdit, 1, 1, 1, 1)
        self.uiImageNameLabel = QtWidgets.QLabel(self.uiImageWizardPage)
        self.uiImageNameLabel.setObjectName("uiImageNameLabel")
        self.gridLayout.addWidget(self.uiImageNameLabel, 1, 0, 1, 1)
        self.verticalLayout_3.addLayout(self.gridLayout)
        DockerVMWizard.addPage(self.uiImageWizardPage)
        self.uiNameWizardPage = QtWidgets.QWizardPage()
        self.uiNameWizardPage.setObjectName("uiNameWizardPage")
        self.formLayout = QtWidgets.QFormLayout(self.uiNameWizardPage)
        self.formLayout.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout.setFormAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.formLayout.setContentsMargins(-1, -1, 0, -1)
        self.formLayout.setObjectName("formLayout")
        self.uiNameLabel = QtWidgets.QLabel(self.uiNameWizardPage)
        self.uiNameLabel.setObjectName("uiNameLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.uiNameLabel)
        self.uiNameLineEdit = QtWidgets.QLineEdit(self.uiNameWizardPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiNameLineEdit.sizePolicy().hasHeightForWidth())
        self.uiNameLineEdit.setSizePolicy(sizePolicy)
        self.uiNameLineEdit.setObjectName("uiNameLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.uiNameLineEdit)
        DockerVMWizard.addPage(self.uiNameWizardPage)
        self.uiAdaptersWizardPage = QtWidgets.QWizardPage()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiAdaptersWizardPage.sizePolicy().hasHeightForWidth())
        self.uiAdaptersWizardPage.setSizePolicy(sizePolicy)
        self.uiAdaptersWizardPage.setObjectName("uiAdaptersWizardPage")
        self.formLayout_2 = QtWidgets.QFormLayout(self.uiAdaptersWizardPage)
        self.formLayout_2.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.formLayout_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout_2.setFormAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_2 = QtWidgets.QLabel(self.uiAdaptersWizardPage)
        self.label_2.setObjectName("label_2")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_2)
        self.uiAdaptersSpinBox = QtWidgets.QSpinBox(self.uiAdaptersWizardPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiAdaptersSpinBox.sizePolicy().hasHeightForWidth())
        self.uiAdaptersSpinBox.setSizePolicy(sizePolicy)
        self.uiAdaptersSpinBox.setMinimum(1)
        self.uiAdaptersSpinBox.setObjectName("uiAdaptersSpinBox")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.uiAdaptersSpinBox)
        DockerVMWizard.addPage(self.uiAdaptersWizardPage)
        self.uiStartCommandWizardPage = QtWidgets.QWizardPage()
        self.uiStartCommandWizardPage.setObjectName("uiStartCommandWizardPage")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.uiStartCommandWizardPage)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label = QtWidgets.QLabel(self.uiStartCommandWizardPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setWordWrap(True)
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        self.uiStartCommandLineEdit = QtWidgets.QLineEdit(self.uiStartCommandWizardPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiStartCommandLineEdit.sizePolicy().hasHeightForWidth())
        self.uiStartCommandLineEdit.setSizePolicy(sizePolicy)
        self.uiStartCommandLineEdit.setObjectName("uiStartCommandLineEdit")
        self.horizontalLayout_2.addWidget(self.uiStartCommandLineEdit)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        DockerVMWizard.addPage(self.uiStartCommandWizardPage)
        self.uiConsoleWizardPage = QtWidgets.QWizardPage()
        self.uiConsoleWizardPage.setObjectName("uiConsoleWizardPage")
        self.formLayout_3 = QtWidgets.QFormLayout(self.uiConsoleWizardPage)
        self.formLayout_3.setObjectName("formLayout_3")
        self.label_6 = QtWidgets.QLabel(self.uiConsoleWizardPage)
        self.label_6.setObjectName("label_6")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_6)
        self.uiConsoleTypeComboBox = QtWidgets.QComboBox(self.uiConsoleWizardPage)
        self.uiConsoleTypeComboBox.setObjectName("uiConsoleTypeComboBox")
        self.uiConsoleTypeComboBox.addItem("")
        self.uiConsoleTypeComboBox.addItem("")
        self.uiConsoleTypeComboBox.addItem("")
        self.uiConsoleTypeComboBox.addItem("")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.uiConsoleTypeComboBox)
        DockerVMWizard.addPage(self.uiConsoleWizardPage)
        self.uiEnvironmentWizardPage = QtWidgets.QWizardPage()
        self.uiEnvironmentWizardPage.setObjectName("uiEnvironmentWizardPage")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.uiEnvironmentWizardPage)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.label_3 = QtWidgets.QLabel(self.uiEnvironmentWizardPage)
        self.label_3.setWordWrap(True)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_4.addWidget(self.label_3)
        self.label_4 = QtWidgets.QLabel(self.uiEnvironmentWizardPage)
        self.label_4.setObjectName("label_4")
        self.verticalLayout_4.addWidget(self.label_4)
        self.label_5 = QtWidgets.QLabel(self.uiEnvironmentWizardPage)
        self.label_5.setObjectName("label_5")
        self.verticalLayout_4.addWidget(self.label_5)
        self.uiEnvironmentTextEdit = QtWidgets.QTextEdit(self.uiEnvironmentWizardPage)
        self.uiEnvironmentTextEdit.setObjectName("uiEnvironmentTextEdit")
        self.verticalLayout_4.addWidget(self.uiEnvironmentTextEdit)
        DockerVMWizard.addPage(self.uiEnvironmentWizardPage)

        self.retranslateUi(DockerVMWizard)
        self.uiConsoleTypeComboBox.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(DockerVMWizard)

    def retranslateUi(self, DockerVMWizard):
        _translate = QtCore.QCoreApplication.translate
        DockerVMWizard.setWindowTitle(_translate("DockerVMWizard", "New Docker VM template"))
        self.uiServerWizardPage.setTitle(_translate("DockerVMWizard", "Server"))
        self.uiServerWizardPage.setSubTitle(_translate("DockerVMWizard", "Please choose a server type to run your new Docker VM."))
        self.uiServerTypeGroupBox.setTitle(_translate("DockerVMWizard", "Server type"))
        self.uiRemoteRadioButton.setText(_translate("DockerVMWizard", "Run the Docker VM on a remote computer"))
        self.uiVMRadioButton.setText(_translate("DockerVMWizard", "Run the Docker VM on the GNS3 VM"))
        self.uiLocalRadioButton.setText(_translate("DockerVMWizard", "Run the Docker VM on your local computer"))
        self.uiRemoteServersGroupBox.setTitle(_translate("DockerVMWizard", "Remote server"))
        self.uiRemoteServersLabel.setText(_translate("DockerVMWizard", "Run on:"))
        self.uiImageWizardPage.setTitle(_translate("DockerVMWizard", "Docker Virtual Machine"))
        self.uiImageWizardPage.setSubTitle(_translate("DockerVMWizard", "Please choose a Docker virtual machine from the list or provide an image name on Docker hub."))
        self.uiExistingImageRadioButton.setText(_translate("DockerVMWizard", "Existing image"))
        self.uiNewImageRadioButton.setText(_translate("DockerVMWizard", "New image"))
        self.uiImageListLabel.setText(_translate("DockerVMWizard", "Image list:"))
        self.uiImageNameLabel.setText(_translate("DockerVMWizard", "Image name:"))
        self.uiNameWizardPage.setTitle(_translate("DockerVMWizard", "Container name"))
        self.uiNameWizardPage.setSubTitle(_translate("DockerVMWizard", "Please choose a descriptive name for your new container"))
        self.uiNameLabel.setText(_translate("DockerVMWizard", "Name:"))
        self.uiAdaptersWizardPage.setTitle(_translate("DockerVMWizard", "Network adapters"))
        self.uiAdaptersWizardPage.setSubTitle(_translate("DockerVMWizard", "Number of adapters attached to the container."))
        self.label_2.setText(_translate("DockerVMWizard", "Adapters:"))
        self.uiStartCommandWizardPage.setTitle(_translate("DockerVMWizard", "Start command"))
        self.uiStartCommandWizardPage.setSubTitle(_translate("DockerVMWizard", "Please enter a start command for the container. The default command will be used if you leave this field empty."))
        self.label.setText(_translate("DockerVMWizard", "Start command:"))
        self.uiConsoleWizardPage.setTitle(_translate("DockerVMWizard", "Console type"))
        self.uiConsoleWizardPage.setSubTitle(_translate("DockerVMWizard", "Please choose the console type. Choosing VNC for your container will run a VNC server listening on a port between 5900 and 6000"))
        self.label_6.setText(_translate("DockerVMWizard", "Console type:"))
        self.uiConsoleTypeComboBox.setItemText(0, _translate("DockerVMWizard", "telnet"))
        self.uiConsoleTypeComboBox.setItemText(1, _translate("DockerVMWizard", "vnc"))
        self.uiConsoleTypeComboBox.setItemText(2, _translate("DockerVMWizard", "http"))
        self.uiConsoleTypeComboBox.setItemText(3, _translate("DockerVMWizard", "https"))
        self.uiEnvironmentWizardPage.setTitle(_translate("DockerVMWizard", "Environment"))
        self.uiEnvironmentWizardPage.setSubTitle(_translate("DockerVMWizard", "These variables will be passed to the container. Please read the container documentation to find what variables are used."))
        self.label_3.setText(_translate("DockerVMWizard", "There must be one pair by line, example: "))
        self.label_4.setText(_translate("DockerVMWizard", "MYSQL_HOST=localhost"))
        self.label_5.setText(_translate("DockerVMWizard", "MYSQL_USER=root"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2015 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os

import logging
log = logging.getLogger(__name__)

from .image import Image


class RegistryError(Exception):
    pass


class Registry:

    def __init__(self, images_dirs):
        self._images_dirs = images_dirs

    def appendImageDirectory(self, image_directory):
        """
        Add a folder to the list of we need to scan

        :param image_directory: Folder we need to add
        """
        self._images_dirs.append(image_directory)

    def search_image_file(self, filename, md5sum, size):
        """
        Search an image based on its MD5 checksum

        :param filename: Image filename (used for ova in order to return the correct file in the archive)
        :param md5sum: Hash of the image
        :param size: File size
        :returns: Image object or None
        """

        for directory in self._images_dirs:
            log.debug("Search images %s (%s) in %s", filename, md5sum, directory)
            if os.path.exists(directory):
                for file in os.listdir(directory):
                    if not file.endswith(".md5sum") and not file.startswith("."):
                        path = os.path.join(directory, file)
                        if os.path.isfile(path):
                            if md5sum is None:
                                if filename == os.path.basename(path):
                                    return Image(path)
                            else:
                                # We take all the file with almost the size of the image
                                # Almost to avoid round issue with system.
                                file_size = os.stat(path).st_size
                                if size is None or (file_size - 10 < size and file_size + 10 > size):
                                    image = Image(path)
                                    if image.md5sum == md5sum:
                                        log.debug("Found images %s (%s) in %s", filename, md5sum, image.path)
                                        return image
                        elif path.endswith(".ova"):
                            if md5sum is None:
                                # File searched in OVA use the notation x.ova/a.vmdk
                                if os.path.dirname(filename) == os.path.basename(path):

                                    path = os.path.join(path, os.path.basename(filename))
                                    log.debug("Found images  %s (%s) from ova in %s", filename, md5sum, path)
                                    return Image(path)
                            else:
                                image = Image(path)
                                if image.md5sum == md5sum:
                                    # File searched in OVA use the notation x.ova/a.vmdk
                                    path = os.path.join(image.path, os.path.basename(filename))
                                    log.debug("Found images  %s (%s) from ova in %s", filename, md5sum, path)
                                    return Image(path)

        return None



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/ui/new_appliance_dialog.ui'
#
# Created: Thu May  5 17:18:11 2016
#      by: PyQt5 UI code generator 5.2.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_NewApplianceDialog(object):
    def setupUi(self, NewApplianceDialog):
        NewApplianceDialog.setObjectName("NewApplianceDialog")
        NewApplianceDialog.setWindowModality(QtCore.Qt.WindowModal)
        NewApplianceDialog.resize(487, 326)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(NewApplianceDialog.sizePolicy().hasHeightForWidth())
        NewApplianceDialog.setSizePolicy(sizePolicy)
        NewApplianceDialog.setModal(True)
        self.verticalLayout = QtWidgets.QVBoxLayout(NewApplianceDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.uiImportApplianceTemplatePushButton = QtWidgets.QPushButton(NewApplianceDialog)
        self.uiImportApplianceTemplatePushButton.setObjectName("uiImportApplianceTemplatePushButton")
        self.verticalLayout.addWidget(self.uiImportApplianceTemplatePushButton)
        self.label = QtWidgets.QLabel(NewApplianceDialog)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.uiAddIOSRouterRadioButton = QtWidgets.QRadioButton(NewApplianceDialog)
        self.uiAddIOSRouterRadioButton.setObjectName("uiAddIOSRouterRadioButton")
        self.verticalLayout.addWidget(self.uiAddIOSRouterRadioButton)
        self.uiAddIOUDeviceRadioButton = QtWidgets.QRadioButton(NewApplianceDialog)
        self.uiAddIOUDeviceRadioButton.setObjectName("uiAddIOUDeviceRadioButton")
        self.verticalLayout.addWidget(self.uiAddIOUDeviceRadioButton)
        self.uiAddQemuVMRadioButton = QtWidgets.QRadioButton(NewApplianceDialog)
        self.uiAddQemuVMRadioButton.setObjectName("uiAddQemuVMRadioButton")
        self.verticalLayout.addWidget(self.uiAddQemuVMRadioButton)
        self.uiAddVirtualBoxVMRadioButton = QtWidgets.QRadioButton(NewApplianceDialog)
        self.uiAddVirtualBoxVMRadioButton.setObjectName("uiAddVirtualBoxVMRadioButton")
        self.verticalLayout.addWidget(self.uiAddVirtualBoxVMRadioButton)
        self.uiAddVMwareVMRadioButton = QtWidgets.QRadioButton(NewApplianceDialog)
        self.uiAddVMwareVMRadioButton.setObjectName("uiAddVMwareVMRadioButton")
        self.verticalLayout.addWidget(self.uiAddVMwareVMRadioButton)
        self.uiAddDockerVMRadioButton = QtWidgets.QRadioButton(NewApplianceDialog)
        self.uiAddDockerVMRadioButton.setObjectName("uiAddDockerVMRadioButton")
        self.verticalLayout.addWidget(self.uiAddDockerVMRadioButton)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(20)
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.uiButtonBox = QtWidgets.QDialogButtonBox(NewApplianceDialog)
        self.uiButtonBox.setOrientation(QtCore.Qt.Horizontal)
        self.uiButtonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Help|QtWidgets.QDialogButtonBox.Ok)
        self.uiButtonBox.setObjectName("uiButtonBox")
        self.horizontalLayout.addWidget(self.uiButtonBox)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(NewApplianceDialog)
        QtCore.QMetaObject.connectSlotsByName(NewApplianceDialog)

    def retranslateUi(self, NewApplianceDialog):
        _translate = QtCore.QCoreApplication.translate
        NewApplianceDialog.setWindowTitle(_translate("NewApplianceDialog", "New appliance template"))
        self.uiImportApplianceTemplatePushButton.setText(_translate("NewApplianceDialog", "Import an appliance template file"))
        self.label.setText(_translate("NewApplianceDialog", "<html><head/><body><p align=\"center\"><span style=\" font-size:x-large; font-weight:600;\">OR</span></p></body></html>"))
        self.uiAddIOSRouterRadioButton.setText(_translate("NewApplianceDialog", "&Add an IOS router using a real IOS image (supported by Dynamips)"))
        self.uiAddIOUDeviceRadioButton.setText(_translate("NewApplianceDialog", "&Add an IOU (IOS on UNIX) device using a L3 or L2 IOU image"))
        self.uiAddQemuVMRadioButton.setText(_translate("NewApplianceDialog", "&Add a Qemu virtual machine"))
        self.uiAddVirtualBoxVMRadioButton.setText(_translate("NewApplianceDialog", "&Add a VirtualBox virtual machine"))
        self.uiAddVMwareVMRadioButton.setText(_translate("NewApplianceDialog", "&Add a VMware virtual machine"))
        self.uiAddDockerVMRadioButton.setText(_translate("NewApplianceDialog", "&Add a Docker container"))

from . import resources_rc



# -*- coding: utf-8 -*-
#
# Copyright (C) 2014 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Configuration page for Dynamips Frame Relay switches.
"""

from gns3.qt import QtCore, QtWidgets
from ..ui.frame_relay_switch_configuration_page_ui import Ui_frameRelaySwitchConfigPageWidget


class FrameRelaySwitchConfigurationPage(QtWidgets.QWidget, Ui_frameRelaySwitchConfigPageWidget):

    """
    QWidget configuration page for Frame Relay switches.
    """

    def __init__(self):

        super().__init__()
        self.setupUi(self)
        self._mapping = {}

        # connect slots
        self.uiAddPushButton.clicked.connect(self._addMappingSlot)
        self.uiDeletePushButton.clicked.connect(self._deleteMappingSlot)
        self.uiMappingTreeWidget.itemActivated.connect(self._mappingSelectedSlot)
        self.uiMappingTreeWidget.itemSelectionChanged.connect(self._mappingSelectionChangedSlot)

        # enable sorting
        self.uiMappingTreeWidget.sortByColumn(0, QtCore.Qt.AscendingOrder)
        self.uiMappingTreeWidget.setSortingEnabled(True)

    def _mappingSelectedSlot(self, item, column):
        """
        Loads a selected mapping from the tree widget.

        :param item: selected QTreeWidgetItem instance
        :param column: ignored
        """

        (source_port, source_dlci) = item.text(0).split(':')
        (destination_port, destination_dlci) = item.text(1).split(':')
        self.uiSourcePortSpinBox.setValue(int(source_port))
        self.uiSourceDLCISpinBox.setValue(int(source_dlci))
        self.uiDestinationPortSpinBox.setValue(int(destination_port))
        self.uiDestinationDLCISpinBox.setValue(int(destination_dlci))

    def _mappingSelectionChangedSlot(self):
        """
        Enables the use of the delete button.
        """

        item = self.uiMappingTreeWidget.currentItem()
        if item is not None:
            self.uiDeletePushButton.setEnabled(True)
        else:
            self.uiDeletePushButton.setEnabled(False)

    def _addMappingSlot(self):
        """
        Adds a new mapping.
        """

        source_port = self.uiSourcePortSpinBox.value()
        source_dlci = self.uiSourceDLCISpinBox.value()
        destination_port = self.uiDestinationPortSpinBox.value()
        destination_dlci = self.uiDestinationDLCISpinBox.value()

        if source_port == destination_port:
            QtWidgets.QMessageBox.critical(self, self._node.name(), "Same source and destination ports")
            return

        source = "{port}:{dlci}".format(port=source_port, dlci=source_dlci)
        destination = "{port}:{dlci}".format(port=destination_port, dlci=destination_dlci)

        if source in self._mapping or destination in self._mapping:
            QtWidgets.QMessageBox.critical(self, self._node.name(), "Mapping already defined")
            return

        item = QtWidgets.QTreeWidgetItem(self.uiMappingTreeWidget)
        item.setText(0, source)
        item.setText(1, destination)
        self.uiMappingTreeWidget.addTopLevelItem(item)
        self.uiSourcePortSpinBox.setValue(source_port + 1)
        self.uiSourceDLCISpinBox.setValue(source_dlci + 1)
        self.uiDestinationPortSpinBox.setValue(destination_port + 1)
        self.uiDestinationDLCISpinBox.setValue(destination_dlci + 1)
        self._mapping[source] = destination

    def _deleteMappingSlot(self):
        """
        Deletes a mapping.
        """

        item = self.uiMappingTreeWidget.currentItem()
        if item:
            # connected_ports = self.node.getConnectedInterfaceList()
            source = item.text(0)
            source_port = int(source.split(':')[0])
            destination = item.text(1)
            destination_port = int(destination.split(':')[0])

            # check that a link isn't connected to these ports
            # before we delete that mapping
            node_ports = self._node.ports()
            for node_port in node_ports:
                if (node_port.portNumber() == source_port or node_port.portNumber() == destination_port) and not node_port.isFree():
                    QtWidgets.QMessageBox.critical(self, self._node.name(), "A link is connected to port {}, please remove it first".format(node_port.name()))
                    return

            del self._mapping[source]
            self.uiMappingTreeWidget.takeTopLevelItem(self.uiMappingTreeWidget.indexOfTopLevelItem(item))

    def loadSettings(self, settings, node, group=False):
        """
        Loads the Frame-Relay switch settings.

        :param settings: the settings (dictionary)
        :param node: Node instance
        :param group: indicates the settings apply to a group
        """

        if not group:
            self.uiNameLineEdit.setText(settings["name"])
        else:
            self.uiNameLineEdit.setEnabled(False)

        self.uiMappingTreeWidget.clear()
        self._mapping = {}
        self._node = node

        for source, destination in settings["mappings"].items():
            item = QtWidgets.QTreeWidgetItem(self.uiMappingTreeWidget)
            item.setText(0, source)
            item.setText(1, destination)
            self.uiMappingTreeWidget.addTopLevelItem(item)
            self._mapping[source] = destination

        self.uiMappingTreeWidget.resizeColumnToContents(0)
        self.uiMappingTreeWidget.resizeColumnToContents(1)

    def saveSettings(self, settings, node, group=False):
        """
        Saves the Frame-Relay switch settings.

        :param settings: the settings (dictionary)
        :param node: Node instance
        :param group: indicates the settings apply to a group
        """

        if not group:
            # set the device name
            name = self.uiNameLineEdit.text()
            if not name:
                QtWidgets.QMessageBox.critical(self, "Name", "Frame relay switch name cannot be empty!")
            else:
                settings["name"] = name
        else:
            del settings["name"]

        settings["mappings"] = self._mapping.copy()
